==> svix-0.84.0.tar.gz: svix-0.84.0/svix/internal/openapi_client/api/message/v1_message_expunge_content.py <==
import random
from time import sleep
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError


def _get_kwargs(
    app_id: str,
    msg_id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/msg/{msg_id}/content/".format(client.base_url, app_id=app_id, msg_id=msg_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> None:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_204 = None
    return response_204


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    app_id: str,
    msg_id: str,
    *,
    client: Client,
) -> None:
    """Expunge Message Content

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str):  Example: unique-app-identifier.
        msg_id (str):  Example: unique-msg-identifier.

    Returns:
        None
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    app_id: str,
    msg_id: str,
    *,
    client: Client,
) -> None:
    """Expunge Message Content

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str):  Example: unique-app-identifier.
        msg_id (str):  Example: unique-msg-identifier.

    Returns:
        None
    """

    return sync_detailed(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )


async def asyncio_detailed(
    app_id: str,
    msg_id: str,
    *,
    client: Client,
) -> None:
    """Expunge Message Content

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str):  Example: unique-app-identifier.
        msg_id (str):  Example: unique-msg-identifier.

    Returns:
        None
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    app_id: str,
    msg_id: str,
    *,
    client: Client,
) -> None:
    """Expunge Message Content

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str):  Example: unique-app-identifier.
        msg_id (str):  Example: unique-msg-identifier.

    Returns:
        None
    """

    return await asyncio_detailed(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )

==> svix-0.85.1.tar.gz: svix-0.85.1/svix/internal/openapi_client/api/message/v1_message_expunge_content.py <==
import random
from time import sleep
from typing import Any, Dict

import httpx

from ...client import AuthenticatedClient
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError


def _get_kwargs(
    app_id: str,
    msg_id: str,
    *,
    client: AuthenticatedClient,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/msg/{msg_id}/content/".format(client.base_url, app_id=app_id, msg_id=msg_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> None:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_204 = None
    return response_204


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    app_id: str,
    msg_id: str,
    *,
    client: AuthenticatedClient,
) -> None:
    """Delete message payload

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        msg_id (str): The msg's ID or UID Example: unique-msg-identifier.

    Returns:
        None
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    app_id: str,
    msg_id: str,
    *,
    client: AuthenticatedClient,
) -> None:
    """Delete message payload

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        msg_id (str): The msg's ID or UID Example: unique-msg-identifier.

    Returns:
        None
    """

    return sync_detailed(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )


async def asyncio_detailed(
    app_id: str,
    msg_id: str,
    *,
    client: AuthenticatedClient,
) -> None:
    """Delete message payload

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        msg_id (str): The msg's ID or UID Example: unique-msg-identifier.

    Returns:
        None
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    app_id: str,
    msg_id: str,
    *,
    client: AuthenticatedClient,
) -> None:
    """Delete message payload

     Delete the given message's payload. Useful in cases when a message was accidentally sent with
    sensitive content.

    The message can't be replayed or resent once its payload has been deleted or expired.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        msg_id (str): The msg's ID or UID Example: unique-msg-identifier.

    Returns:
        None
    """

    return await asyncio_detailed(
        app_id=app_id,
        msg_id=msg_id,
        client=client,
    )
